#ifndef NT2_INCLUDE_CONSTANTS_MFOUR_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MFOUR_HPP_INCLUDED

#include <nt2/constant/include/constants/mfour.hpp>

#endif
